
/*
Voter Response to Peak and End Transfers: Evidence from a Conditional Cash Transfer Experiment
Sebastian Galiani, Nadya Hajj, Patrick J. McEwan, Pablo Ibarrarán, and Nandita Krishnaswamy
American Economic Journal: Economic Policy

Final code: October 23, 2018
Email pmcewan@wellesley.edu with questions, comments, or errors.
*/

* Code used to prepare Tables A1 and A2 in online appendix A
* User must obtain Honduran DHS, 2011-12: https://dhsprogram.com/what-we-do/survey/survey-display-369.cfm
* In addition to DHS files, the code merges a file containing variables that measure extreme poverty rates and 2009 voting outcomes. The file was created with restricted-use DHS data on GPS coordinates of each survey cluster. See online appendix A for details.

clear
cd ".../20170448_data" // Update user directory
set more off

* Assemble household-level data

* Household structure
use "DHS/HNPR62FL.DTA",clear
recode hv105 98=. 99=.
gen ch0to5=1 if hv105>=0 & hv105<=5
gen ch6to18=1 if hv105>=6 & hv105<=18
gen totalhh=1
gen schooling=hv108 if hv101==1
recode schooling 98=. 99=.
collapse (max) schooling (sum) ch0to5 ch6to18 totalhh,by(hv001 hv002)
save tempkids,replace

* Currently pregnant from women's questionnaire
use "DHS/HNIR62FL.DTA",clear
rename v213 pregnant
gen anypregnant=0
replace anypregnant=1 if pregnant==1
collapse (max) anypregnant,by(v001 v002)
save temppreg,replace

* Household questionnaire
use "DHS/HNHR62FL.DTA",clear
gen rural=hv025
recode rural 2=1 1=0

* Bono 10000 indicator
gen bono=sh152
recode bono 8=. 9=.

* Month of survey
gen month=ym( hv007, hv006)

* Dwelling
gen dirtfloor= hv213
recode dirtfloor 11=1 21/96=0 99=.
gen sewerseptic=hv205
recode sewerseptic 11=1 12=1 13=1 14/96=0 99=.

* Household assets
foreach v in sh131a sh131b sh131c sh131d sh131e sh131f sh131l hv207 hv208 hv209 hv210 hv211 hv212 hv221 hv243a {
	recode `v' 9=.
	}
rename sh131a table
rename sh131b chair
rename sh131c bed
rename sh131d dresser
rename sh131e fan
rename sh131f ac
rename sh131l computer
rename hv207 radio
rename hv208 tv
rename hv209 refrigerator
rename hv210 bicycle
rename hv211 motorcycle
rename hv212 car
rename hv221 landline
rename hv243a cell
qui pca table chair bed dresser fan ac computer radio tv refrigerator bicycle motorcycle car landline cell
predict temp
egen assets=std(temp)
drop temp

* Merge files
merge m:1 hv001 hv002 using tempkids
drop _merge
erase tempkids.dta
gen v001=hv001
gen v002=hv002
merge m:1 v001 v002 using temppreg
erase temppreg.dta
drop _merge
rename hv001 cluster
merge m:1 cluster using "DHS/dhs_covariates" // 450 unmatched given missing GPS coordinates
drop _merge

* Some recodes
recode ch0to5 0=0 1/max=1
recode ch6to18 0=0 1/max=1
recode anypregnant .=0

* Sample
egen miss=rowmiss(bono extremepoverty rural dirtfloor sewerseptic assets schooling totalhh ch0to5 ch6to18 anypregnant share_mun swing_mun)
keep if miss==0

* Table A1: Descriptive Statistics on Households in the 2011-2012 Demographic and Health Survey
preserve
keep bono share_mun swing_mun extremepoverty rural dirtfloor sewerseptic assets schooling totalhh ch0to5 ch6to18 anypregnant 
order bono extremepoverty rural dirtfloor sewerseptic assets schooling totalhh ch0to5 ch6to18 anypregnant share_mun swing_mun
outreg2 using table_a1, sum(log) eqkeep(mean sd N) replace
outreg2 using table_a1 if bono==1, sum(log) eqkeep(mean sd N) 
outreg2 using table_a1 if bono==0, sum(log) eqkeep(mean sd N) 
restore

* Table A2: Correlates of Household Participation in Bono 10,000
outreg,clear
reg bono extremepoverty rural  dirtfloor sewerseptic assets schooling totalhh ch0to5 ch6to18 anypregnant share_mun swing_mun i.month, cluster(cluster)
		outreg, merge se starlevels(10 5 1) starloc(1) nocons bdec(3) nodisplay
reg bono extremepoverty rural  dirtfloor sewerseptic assets schooling totalhh  ch0to5 ch6to18 anypregnant share_mun swing_mun i.month if extremepoverty<.5, cluster(cluster)
		outreg, merge se starlevels(10 5 1) starloc(1) nocons bdec(3) nodisplay
reg bono extremepoverty rural  dirtfloor sewerseptic assets schooling totalhh  ch0to5 ch6to18 anypregnant share_mun swing_mun i.month if extremepoverty>=.5, cluster(cluster)
		outreg, merge se starlevels(10 5 1) starloc(1) nocons bdec(3) nodisplay
outreg using table_a2, replay replace landscape 

exit
